==> haskell-hosc-0.17-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hosc
version:              0.17
visibility:           public
id:                   hosc-0.17-LU9bhazLsXPFJ5aXrY3t8j
key:                  hosc-0.17-LU9bhazLsXPFJ5aXrY3t8j
license:              GPL-3.0-only
copyright:            (c) Rohan Drape, Stefan Kersten and others, 2007-2018
maintainer:           rd@rohandrape.net
author:               Rohan Drape, Stefan Kersten
stability:            Experimental
homepage:             http://rohandrape.net/t/hosc
synopsis:             Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.

    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".

category:             Sound
abi:                  4d302a8568d104b1c44d6850c3f2ff8b
exposed:              True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait

import-dirs:          /usr/lib/ghc-8.8.1/site-local/hosc-0.17
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hosc-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hosc-0.17
hs-libraries:         HShosc-0.17-LU9bhazLsXPFJ5aXrY3t8j
depends:
    base-4.13.0.0 binary-0.8.7.0
    blaze-builder-0.4.1.0-3xTNie2AGY1AnFlpxCbxSb bytestring-0.10.9.0
    data-binary-ieee754-0.4.4-JFCv5iwsUHQ3ijGpBz7Bjn
    network-2.8.0.1-7k4XOYkWuzJL3fZ1ktoWWP time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html:         /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hosc-0.17-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hosc
version:              0.17
visibility:           public
id:                   hosc-0.17-K0wzn8iPgzCAwDPNTAyW4U
key:                  hosc-0.17-K0wzn8iPgzCAwDPNTAyW4U
license:              GPL-3.0-only
copyright:            (c) Rohan Drape, Stefan Kersten and others, 2007-2018
maintainer:           rd@rohandrape.net
author:               Rohan Drape, Stefan Kersten
stability:            Experimental
homepage:             http://rohandrape.net/t/hosc
synopsis:             Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.

    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".

category:             Sound
abi:                  8db219782aade21b95c145399aaa0845
exposed:              True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait

import-dirs:          /usr/lib/ghc-8.8.1/site-local/hosc-0.17
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hosc-0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hosc-0.17
hs-libraries:         HShosc-0.17-K0wzn8iPgzCAwDPNTAyW4U
depends:
    base-4.13.0.0 binary-0.8.7.0
    blaze-builder-0.4.1.0-3xTNie2AGY1AnFlpxCbxSb bytestring-0.10.9.0
    data-binary-ieee754-0.4.4-JFCv5iwsUHQ3ijGpBz7Bjn
    network-2.8.0.1-LoLpkHQvMiDKCthSusWHQL time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html:         /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
